@@ -1,5 +1,6 @@
 #![doc(html_favicon_url = "https://v2.nonebot.dev/logo.png")]
 #![doc(html_logo_url = "https://v2.nonebot.dev/logo.png")]
+#![cfg_attr(docsrs, feature(doc_cfg))]
 
 //! Nonebot-rs 简称 nbrs，是一个基于 Nonebot2 思路的 Onebot 协议机器人框架 Rust 实现。
 //! 本框架的基本目标是实现比较便利的 Rust Onebot 机器人搭建。长期目标是以本项目为基础，
@@ -55,7 +56,7 @@
 //! Matcher 开发：
 //!
 //! ```rust
-//! use crate::matcher::prelude::*;
+//! use nonebot_rs::matcher::prelude::*;
 //! use rcnb_rs::encode;
 //!
 //! #[derive(Clone)]   // handler struct 需要生成 Clone trait
@@ -132,16 +133,16 @@
 //! }
 //! ```
 //!
-//! 在你的入口文件 `main.rs` 注册定时任务
+//! 注册定时任务
 //!
 //! ```rust
 //! use nonebot_rs;
 //!
 //! fn main() {
-//! let mut nb = nonebot_rs::Nonebot::new();
-//!     .add_message_matchers(r6s());
-//! nb.scheduler.add(clock::clock(&nb)).unwrap();
-//! nb.run()
+//!     let mut nb = nonebot_rs::Nonebot::new();
+//!         .add_message_matchers(r6s());
+//!     nb.scheduler.add(clock(&nb)).unwrap();
+//!     nb.run()
 //! }
 //! ```
 //!
@@ -167,20 +168,24 @@ pub mod event;
 pub mod log;
 /// Matcher 定义
 #[cfg(feature = "matcher")]
+#[cfg_attr(docsrs, doc(cfg(feature = "matcher")))]
 pub mod matcher;
 #[doc(hidden)]
 pub mod message;
 mod plugin;
 #[doc(hidden)]
 #[cfg(feature = "pyo")]
+#[cfg_attr(docsrs, doc(cfg(feature = "pyo")))]
 pub mod pyo;
 mod utils;
 
 use std::collections::HashMap;
 use tokio::sync::{mpsc, watch};
 #[cfg(feature = "scheduler")]
+#[cfg_attr(docsrs, doc(cfg(feature = "scheduler")))]
 pub use tokio_cron_scheduler::Job;
 #[cfg(feature = "scheduler")]
+#[cfg_attr(docsrs, doc(cfg(feature = "scheduler")))]
 use tokio_cron_scheduler::JobScheduler;
 
 #[doc(inline)]
@@ -192,6 +197,7 @@ pub use async_trait::async_trait;
 pub use bot::Bot;
 #[doc(inline)]
 #[cfg(feature = "matcher")]
+#[cfg_attr(docsrs, doc(cfg(feature = "matcher")))]
 pub use matcher::matchers::{Matchers, MatchersBTreeMap, MatchersHashMap};
 #[doc(inline)]
 pub use message::Message;
